==> nextcloud-30.0.5.tgz: nextcloud/apps/photos/l10n/ast.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Enllaz públicu",
    "Photos" : "Semeyes",
    "On This Day" : "Tal día como güei",
    "Your memories under your control" : "Los tos recuerdos baxo control",
    "All media" : "Tolos medios",
    "Videos" : "Vídeos",
    "Albums" : "Álbumes",
    "Collaborative albums" : "Álbumes collaborativos",
    "People" : "Persones",
    "Folders" : "Carpetes",
    "Favorites" : "Favoritos",
    "On this day" : "Tal día como güei",
    "Shared with you" : "Compartióse contigo",
    "Tags" : "Etiquetes",
    "Places" : "Llugares",
    "Map" : "Mapa",
    "Photos settings" : "Configuración de Semeyes",
    "Mark selection as favorite" : "Marcar la seleición como favorita",
    "Add selection to favorites" : "Meter la seleición en Favoritos",
    "Remove selection from favorites" : "Quitar la seleición de Favoritos",
    "Name of the album" : "Nome del álbum",
    "Location of the album" : "Llocalización el álbum",
    "Back" : "Atrás",
    "Add collaborators" : "Amestar collaboradores",
    "Save" : "Guardar",
    "Create album" : "Crear un álbum",
    "Add to Album" : "Amestar al álbum",
    "Add selection to album {albumName}" : "Amestar la seleición al álbum «{albumName}»",
    "Shared by" : "Compartíu por",
    "Create a new album." : "Crear un álbum.",
    "Create new album" : "Crear un álbum",
    "New album" : "Álbum nuevu",
    "_%n item_::_%n photos and videos_" : ["%n elementu","%n elementos"],
    "Add people or groups who can edit your album" : "Amiesta a persones u grupos que puedan editar l'álbum",
    "Search people or groups" : "Buscar persones o grupos",
    "No recommendations. Start typing." : "Nun hai nenguna recomendación. Comienza a escribir.",
    "Group" : "Grupu",
    "Remove {collaboratorLabel} from the collaborators list" : "Quitar «{collaboratorLabel}» de la llista de collaboradores",
    "Copy the public link" : "Copiar l'enllaz públicu",
    "Public link copied!" : "¡Copióse l'enllaz públicu!",
    "Copy public link" : "Copiar l'enllaz públicu",
    "Delete the public link" : "Desaniciar l'enllaz públicu",
    "Create public link share" : "Crear un elementu públicu per enllaz públicu",
    "Share via public link" : "Compartir per un enllaz públicu",
    "Failed to fetch collaborators list." : "Nun se pue dir en cata de la llista de collaboradores.",
    "Failed to update album." : "Nun se pue anovar l'álbum.",
    "This collection does not exist" : "Esta coleición nun esiste",
    "An error occurred" : "Prodúxose un error",
    "No picture for this day" : "Nun hai nenguna semeya pa esti día",
    "Picture taken on this day will show up here." : "Equí apaecen les semeyes feches nesti día.",
    "More photos from this day" : "Más semeyes d'esti día",
    "_%n unassigned photo_::_%n unassigned photos_" : ["%n semeya ensin asignar","%n semeyes ensin asignar"],
    "Favorite" : "Meter en Favoritos",
    "Select image {imageName}" : "Seleicionar la imaxe «{imageName}»",
    "Favorite image, open the full size \"{name}\" image" : "Imaxe favorita, abrir la imaxe «{name}» a tamañu completu",
    "Open the full size \"{name}\" image" : "Abrir la imaxe «{name}» a tamañu completu",
    "Open the \"{name}\" folder" : "Abrir la carpeta «{name}»",
    "Go back" : "Dir p'atrás",
    "Back to {folder}" : "Volver a «{folder}»",
    "Share this folder" : "Compartir esta carpeta",
    "Dates" : "Dates",
    "Jump to specific date in list" : "Saltar a una data específica de la llista",
    "Jump to {date}" : "Saltar a «{date}»",
    "Add to {destination}" : "Amestar a {destination}",
    "There are no photos or videos yet!" : "¡Nun hai nenguna semeya nin nengún videu!",
    "_{years} year ago_::_{years} years ago_" : ["hai {years} añu","hai {years} años"],
    "Enable squared photos view" : "Activar la vista de semeyes en cuadráu",
    "Delete source directory" : "Desaniciar el direutoriu d'orixe",
    "All folders" : "Toles carpetes",
    "Add a Photos source for the timelines" : "Amestar una fonte de semeyes pa les llinies de tiempu",
    "Add folder" : "Amestar una carpeta",
    "Select a source folder for your media" : "Seleiciona una carpeta d'orixe pa los elementos multimedia",
    "Home" : "Aniciu",
    "Choose default Photos upload and Albums location" : "Escueyi la llocalización pa los álbumes y la xuba de semeyes",
    "Choose a different folder" : "Escueyi una carpeta diferente",
    "Select the default upload location for your media" : "Seleiciona la llocalización de xuba predeterminada pa los elementos multimedia",
    "View" : "Ver",
    "Media folders" : "Carpetes multimedia",
    "Choose the folders from where photos and videos are shown." : "Escueyi les carpetes de les que s'amuesen les semeyes y vídeos.",
    "Upload folder" : "Carpeta de xuba",
    "Choose the folder where photos and albums are uploaded to." : "Escueyu la carpeta a onde se xuben les semeyes y los álbumes.",
    "_%n photo_::_%n photos_" : ["%n semeya","%n semeyes"],
    "Unselect all" : "Deseleicionar too",
    "Manage collaborators for this album" : "Xestiona los collaboradores d'esti álbum",
    "Open actions menu" : "Abrir el menú d'aiciones",
    "Edit album details" : "Editar los detalles del álbum",
    "Download all files in album" : "Baxar tolos ficheros del álbum",
    "Delete album" : "Desaniciar l'álbum",
    "Download selected files" : "Baxar los ficheros seleicionaos",
    "Remove selection from album" : "Quitar la seleición del álbum",
    "This album does not have any photos or videos yet!" : "¡Esti álbum nun tien nenguna semeya nin nengún videu!",
    "Add photos to this album" : "Amestar semeyes a esti álbum",
    "Add photos to {albumName}" : "Amestar semeyes a «{albumName}»",
    "Manage collaborators" : "Xestionar los collaboradores",
    "Save collaborators for this album." : "Guarda los collaboradores d'esti álbum.",
    "Cover photo for album {albumName}" : "Portada del álbum {albumName}",
    "There is no album yet!" : "¡Nun hai nengún álbum!",
    "This person could not be found" : "Nun se pudo atopar a esta persona",
    "Rename person" : "Renomar la persona",
    "Merge with different person" : "Mecer con otra persona",
    "Download selected photos" : "Baxar les semeyes seleicionaes",
    "Remove from favorites" : "Quitar de Favoritos",
    "Remove person" : "Quitar la persona",
    "Name of this person" : "Nome d'esta persona",
    "Save." : "Guardar.",
    "Merge person" : "Mecer la persona",
    "Move to different person" : "Mover a una persona diferente",
    "_Move photo to a different person_::_Move photos to a different person_" : ["Mover la semeya a una persona diferente","Mover les semeyes a una persona diferente"],
    "_Remove photo from person_::_Remove photos from person_" : ["Quitar la semeya d'esta persona","Quitar les semeyes d'esta persona"],
    "This might take some time depending on the size of your photo library." : "Quiciabes esta operación tarde tiempu según el tamañu de la biblioteca de semeyes.",
    "Recognized people will show up here" : "Equí apaecen les persones que se reconozan",
    "This folder does not exist" : "Esta carpeta nun esiste",
    "Loading folders …" : "Cargando les carpetes…",
    "No photos in here" : "Equí nun hai nenguna semeya",
    "Taken on {date} at {time}" : "Fízose'l {date} a la hora {time}",
    "This place does not have any photos or videos yet!" : "¡Esti llugar nun tien nenguna semeya nin nengún videu!",
    "Add photos to this place" : "Amestar semeyes a esti llugar",
    "Cover photo for place {placeName}" : "Portada pal llugar «{placeName}»",
    "There is no place yet!" : "¡Nun hai nengún llugar!",
    "Cover photo for shared album {albumName}." : "Portada pal álbum compartíu «{albumName}».",
    "Back to tags overview" : "Volver a la vista xeneral d'etiquetes",
    "No photos with this tag yet" : "Nun hai nenguna semeya con esta etiqueta",
    "No tags yet" : "Nun hai nenguna etiqueta",
    "Photos with tags will show up here" : "Equí apaecen les semeyes etiquetaes",
    "Popular tags" : "Etiquetes populares",
    "Add" : "Amestar",
    "Add to album" : "Amestar al álbum",
    "Delete selection" : "Desaniciar la seleición",
    "No photos or videos in here" : "Equí nun hai nenguna semeya nin nengún videu",
    "Unassigned faces" : "Cares ensin asignar",
    "_%n photos_::_%n photos_" : ["%n semeya","%n semeyes"],
    "Failed to fetch collection." : "Nun se pue dir en cata de la coleición.",
    "Failed to fetch collections list." : "Nun se pue dir en cata de la llista de les coleiciones",
    "Failed to fetch faces list." : "Nun se pue dir en cata de la llista de cares",
    "All your media" : "Tolos elementos multimedia",
    "Album {title}" : "Álbum «{title}»",
    "Shared Albums" : "Álbumes compartíos",
    "Shared album {title}" : "Álbum compartíu «{title}»",
    "Public album {title}" : "Álbum públicu «{title}»",
    "Tagged photos" : "Semeyes etiquetaes",
    "Tagged photo {title}" : "Semeya etiqueta «{title}»",
    "{title}'s face" : "Cara de: {title}",
    "{startDate} to {endDate}" : "{startDate} hasta'l {endDate}",
    "Details" : "Detalles",
    "Failed to rename {oldName} to {faceName}." : "Nun se pue renomar «{oldName}» a «{faceName}».",
    "Failed to delete {faceName}." : "Nun se pue desaniciar «{faceName}».",
    "Failed to delete {fileId}." : "Nun se pue desaniciar «{fileId}».",
    "Failed to delete {fileName}." : "Nun se pue desaniciar «{fileName}»",
    "Failed to set favorite state for {fileId}." : "Nun se pue afitar l'estáu favoritu de: {fileId}",
    "Failed to set favorite state for {fileName}." : "Nun se pue afitar l'estáu favoritu de: {fileName}",
    "Could not load photos folder" : "Nun se puen cargar la carpeta de semeyes",
    "Default Photos upload and Albums location" : "Llocalización predeterminada de los álbumes y la xuba de semeyes",
    "Select the default location for your media" : "Seleiciona la llocalización predeterminada pa los elementos multimedia",
    "Invalid location selected" : "Seleicionóse una llocalización inválida",
    "Photos directory" : "Direutoriu de datos",
    "One of the source folders does not exists" : "Nun esiste una de les carpetes d'orixe"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-31.0.9.tgz: nextcloud/apps/photos/l10n/ast.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Enllaz públicu",
    "Photos" : "Semeyes",
    "On This Day" : "Tal día como güei",
    "Your memories under your control" : "Los tos recuerdos baxo control",
    "All media" : "Tolos medios",
    "Videos" : "Vídeos",
    "Albums" : "Álbumes",
    "Collaborative albums" : "Álbumes collaborativos",
    "People" : "Persones",
    "Folders" : "Carpetes",
    "Favorites" : "Favoritos",
    "On this day" : "Tal día como güei",
    "Shared with you" : "Compartióse contigo",
    "Tags" : "Etiquetes",
    "Places" : "Llugares",
    "Map" : "Mapa",
    "Photos settings" : "Configuración de Semeyes",
    "Mark selection as favorite" : "Marcar la seleición como favorita",
    "Add selection to favorites" : "Meter la seleición en Favoritos",
    "Remove selection from favorites" : "Quitar la seleición de Favoritos",
    "Name of the album" : "Nome del álbum",
    "Location of the album" : "Llocalización el álbum",
    "Back" : "Atrás",
    "Add collaborators" : "Amestar collaboradores",
    "Save" : "Guardar",
    "Create album" : "Crear un álbum",
    "Add to Album" : "Amestar al álbum",
    "Add selection to album {albumName}" : "Amestar la seleición al álbum «{albumName}»",
    "Shared by" : "Compartíu por",
    "Create a new album." : "Crear un álbum.",
    "Create new album" : "Crear un álbum",
    "New album" : "Álbum nuevu",
    "_%n item_::_%n photos and videos_" : ["%n elementu","%n elementos"],
    "Failed to fetch collaborators list." : "Nun se pue dir en cata de la llista de collaboradores.",
    "Failed to update album." : "Nun se pue anovar l'álbum.",
    "Add people or groups who can edit your album" : "Amiesta a persones u grupos que puedan editar l'álbum",
    "Search people or groups" : "Buscar persones o grupos",
    "No recommendations. Start typing." : "Nun hai nenguna recomendación. Comienza a escribir.",
    "Copy the public link" : "Copiar l'enllaz públicu",
    "Public link copied!" : "¡Copióse l'enllaz públicu!",
    "Copy public link" : "Copiar l'enllaz públicu",
    "Delete the public link" : "Desaniciar l'enllaz públicu",
    "Create public link share" : "Crear un elementu públicu per enllaz públicu",
    "Share via public link" : "Compartir per un enllaz públicu",
    "This collection does not exist" : "Esta coleición nun esiste",
    "An error occurred" : "Prodúxose un error",
    "No picture for this day" : "Nun hai nenguna semeya pa esti día",
    "Picture taken on this day will show up here." : "Equí apaecen les semeyes feches nesti día.",
    "More photos from this day" : "Más semeyes d'esti día",
    "_%n photos_::_%n photos_" : ["%n semeya","%n semeyes"],
    "_%n unassigned photo_::_%n unassigned photos_" : ["%n semeya ensin asignar","%n semeyes ensin asignar"],
    "Favorite" : "Meter en Favoritos",
    "Favorite image, open the full size \"{name}\" image" : "Imaxe favorita, abrir la imaxe «{name}» a tamañu completu",
    "Open the full size \"{name}\" image" : "Abrir la imaxe «{name}» a tamañu completu",
    "Select image {imageName}" : "Seleicionar la imaxe «{imageName}»",
    "Open the \"{name}\" folder" : "Abrir la carpeta «{name}»",
    "Go back" : "Dir p'atrás",
    "Dates" : "Dates",
    "Jump to specific date in list" : "Saltar a una data específica de la llista",
    "Jump to {date}" : "Saltar a «{date}»",
    "Add to {destination}" : "Amestar a {destination}",
    "There are no photos or videos yet!" : "¡Nun hai nenguna semeya nin nengún videu!",
    "_{years} year ago_::_{years} years ago_" : ["hai {years} añu","hai {years} años"],
    "Enable squared photos view" : "Activar la vista de semeyes en cuadráu",
    "Delete source directory" : "Desaniciar el direutoriu d'orixe",
    "Select a source folder for your media" : "Seleiciona una carpeta d'orixe pa los elementos multimedia",
    "All folders" : "Toles carpetes",
    "Add a Photos source for the timelines" : "Amestar una fonte de semeyes pa les llinies de tiempu",
    "Add folder" : "Amestar una carpeta",
    "Select the default upload location for your media" : "Seleiciona la llocalización de xuba predeterminada pa los elementos multimedia",
    "Home" : "Aniciu",
    "Choose default Photos upload and Albums location" : "Escueyi la llocalización pa los álbumes y la xuba de semeyes",
    "Choose a different folder" : "Escueyi una carpeta diferente",
    "View" : "Ver",
    "Media folders" : "Carpetes multimedia",
    "Choose the folders from where photos and videos are shown." : "Escueyi les carpetes de les que s'amuesen les semeyes y vídeos.",
    "Upload folder" : "Carpeta de xuba",
    "Choose the folder where photos and albums are uploaded to." : "Escueyu la carpeta a onde se xuben les semeyes y los álbumes.",
    "_%n photo_::_%n photos_" : ["%n semeya","%n semeyes"],
    "Unselect all" : "Deseleicionar too",
    "Add photos to this album" : "Amestar semeyes a esti álbum",
    "Manage collaborators for this album" : "Xestiona los collaboradores d'esti álbum",
    "Open actions menu" : "Abrir el menú d'aiciones",
    "Edit album details" : "Editar los detalles del álbum",
    "Download all files in album" : "Baxar tolos ficheros del álbum",
    "Delete album" : "Desaniciar l'álbum",
    "Download selected files" : "Baxar los ficheros seleicionaos",
    "Remove selection from album" : "Quitar la seleición del álbum",
    "This album does not have any photos or videos yet!" : "¡Esti álbum nun tien nenguna semeya nin nengún videu!",
    "Add photos to {albumName}" : "Amestar semeyes a «{albumName}»",
    "Manage collaborators" : "Xestionar los collaboradores",
    "Save collaborators for this album." : "Guarda los collaboradores d'esti álbum.",
    "Cover photo for album {albumName}" : "Portada del álbum {albumName}",
    "There is no album yet!" : "¡Nun hai nengún álbum!",
    "This person could not be found" : "Nun se pudo atopar a esta persona",
    "Rename person" : "Renomar la persona",
    "Merge with different person" : "Mecer con otra persona",
    "Download selected photos" : "Baxar les semeyes seleicionaes",
    "Remove from favorites" : "Quitar de Favoritos",
    "Remove person" : "Quitar la persona",
    "Name of this person" : "Nome d'esta persona",
    "Save." : "Guardar.",
    "Merge person" : "Mecer la persona",
    "Move to different person" : "Mover a una persona diferente",
    "_Move photo to a different person_::_Move photos to a different person_" : ["Mover la semeya a una persona diferente","Mover les semeyes a una persona diferente"],
    "_Remove photo from person_::_Remove photos from person_" : ["Quitar la semeya d'esta persona","Quitar les semeyes d'esta persona"],
    "This might take some time depending on the size of your photo library." : "Quiciabes esta operación tarde tiempu según el tamañu de la biblioteca de semeyes.",
    "Recognized people will show up here" : "Equí apaecen les persones que se reconozan",
    "This folder does not exist" : "Esta carpeta nun esiste",
    "No photos in here" : "Equí nun hai nenguna semeya",
    "Taken on {date} at {time}" : "Fízose'l {date} a la hora {time}",
    "This place does not have any photos or videos yet!" : "¡Esti llugar nun tien nenguna semeya nin nengún videu!",
    "Add photos to this place" : "Amestar semeyes a esti llugar",
    "Cover photo for place {placeName}" : "Portada pal llugar «{placeName}»",
    "There is no place yet!" : "¡Nun hai nengún llugar!",
    "Back to tags overview" : "Volver a la vista xeneral d'etiquetes",
    "No photos with this tag yet" : "Nun hai nenguna semeya con esta etiqueta",
    "No tags yet" : "Nun hai nenguna etiqueta",
    "Photos with tags will show up here" : "Equí apaecen les semeyes etiquetaes",
    "Popular tags" : "Etiquetes populares",
    "Add to album" : "Amestar al álbum",
    "Delete selection" : "Desaniciar la seleición",
    "No photos or videos in here" : "Equí nun hai nenguna semeya nin nengún videu",
    "Unassigned faces" : "Cares ensin asignar",
    "Failed to fetch collection." : "Nun se pue dir en cata de la coleición.",
    "Failed to fetch collections list." : "Nun se pue dir en cata de la llista de les coleiciones",
    "Failed to fetch faces list." : "Nun se pue dir en cata de la llista de cares",
    "All your media" : "Tolos elementos multimedia",
    "Album {title}" : "Álbum «{title}»",
    "Shared Albums" : "Álbumes compartíos",
    "Shared album {title}" : "Álbum compartíu «{title}»",
    "Public album {title}" : "Álbum públicu «{title}»",
    "Tagged photos" : "Semeyes etiquetaes",
    "Tagged photo {title}" : "Semeya etiqueta «{title}»",
    "{title}'s face" : "Cara de: {title}",
    "Last week" : "La selmana anterior",
    "{startDate} to {endDate}" : "{startDate} hasta'l {endDate}",
    "Details" : "Detalles",
    "Could not load photos folder" : "Nun se puen cargar la carpeta de semeyes",
    "Group" : "Grupu",
    "Remove {collaboratorLabel} from the collaborators list" : "Quitar «{collaboratorLabel}» de la llista de collaboradores",
    "Back to {folder}" : "Volver a «{folder}»",
    "Share this folder" : "Compartir esta carpeta",
    "Loading folders …" : "Cargando les carpetes…",
    "One of the source folders does not exists" : "Nun esiste una de les carpetes d'orixe",
    "Add" : "Amestar"
},
"nplurals=2; plural=(n != 1);");
